pref("inspector.blink.border-color", "#CC0000");
pref("inspector.blink.border-width", 2);
pref("inspector.blink.duration", 2);
pref("inspector.blink.on", true);
pref("inspector.blink.speed", 100);
pref("inspector.dom.columns", "localName,@id");
