/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is Mozilla MathML Project.
 *
 * The Initial Developer of the Original Code is The University Of
 * Queensland.  Portions created by The University Of Queensland are
 * Copyright (C) 1999 The University Of Queensland.  All Rights Reserved.
 *
 * Contributor(s):
 *   Roger B. Sidje <rbs@maths.uq.edu.au>
 */


/*******************************************************/
/* namespace for MathML elements                       */
/*******************************************************/

@namespace url(http://www.w3.org/1998/Math/MathML); 


/*******************************************************/
/* <math> - outermost math element                     */
/*******************************************************/

math {
  display: inline;
  font-size: inherit;
  font-style: normal;
  font-family: CMSY10, CMEX10, Symbol, Times, Lucida Sans Unicode, MT Extra, Math1, Math2, Math3, Math4, Math5, serif;
}

math[mode="inline"] {
  display: inline;
}

math[mode="display"] {
  display: block;
  text-align: -moz-center;
}

:-moz-math-inline {
  display: inline;
}

:-moz-math-table {
  display: table;
}

/*******************************************************/
/* attributes common to all tags                       */
/*******************************************************/

[fontstyle="normal"] {
  font-style: normal;
}

[fontstyle="italic"] {
  font-style: italic;
}

[fontweight="normal"] {
  font-weight: normal;
}

[fontweight="bold"] {
  font-weight: bold;
}

[fontsize="xx-small"] {
  font-size: xx-small;
}

[fontsize="x-small"] {
  font-size: x-small;
}

[fontsize="small"], [fontsize="smaller"] {
  font-size: smaller;
}

[fontsize="medium"] {
  font-size: medium;
}

[fontsize="large"] {
  font-size: large;
}

[fontsize="larger"] {
  font-size: larger;
}

[fontsize="x-large"] {
  font-size: x-large;
}

[fontsize="xx-large"] {
  font-size: xx-large;
}

/*******************************************************/
/* tags with generated content                         */
/*******************************************************/

ms {
  display: inline;
}

ms:before {
  content: open-quote;
}

ms:after {
  content: close-quote;
}

merror {
  display: block;
  font-family: sans-serif;
  font-weight: bold;
  white-space: pre;
  margin: 1em;
  padding: 1em;
  border-width: thin;
  border-style: inset;
  border-color: red;
  font-size: 14pt;
  background-color: lightyellow;
}

/*******************************************************/
/* mtable and its related tags                         */
/*******************************************************/

mtable {
  display: table;
  text-align: -moz-center;
  border-spacing: 0.8em 1.0ex; /* horizontal vertical */
  border-collapse: separate; /* 'collapse' is blocked by bug 49490 */
  margin-left: -0.4em;
  margin-right: -0.8em;
  margin-top: -1.0ex;
  margin-bottom: -1.0ex;
  /* margin: 0.5ex 0.4em 0.5ex 0.4em;  top right bottom left */
  -moz-box-sizing: border-box;
  /* -moz-box-sizing: content-box; */
}

mtr {
  display: table-row;
  text-align: inherit;
  vertical-align: baseline;
}

/* must never set padding in td, th */

mtd {
  display: table-cell;
  text-align: inherit; 
  vertical-align: inherit;
  white-space: nowrap;
}

/***********************/
/* -- mtd: columnalign */

mtd[columnalign="left"] {
  text-align: left;
}

mtd[columnalign="right"] {
  text-align: right;
}

mtd[columnalign="center"] {
  text-align: -moz-center;
}

/********************/
/* -- mtd: rowalign */

mtd[rowalign="top"] {
  vertical-align: top;
}

mtd[rowalign="bottom"] {
  vertical-align: bottom;
}

mtd[rowalign="center"] {
  vertical-align: middle;
}

mtd[rowalign="baseline"] {
  vertical-align: baseline;
}

/* -- not yet supported --
mtd[rowalign="axis"] {
  vertical-align: mathline;
}
*/

/*******************************************************/
/* style switching during frame construction           */
/*******************************************************/

/* change of style depending on the context of <mi> */

mi {
  font-style: italic;
}

[-moz-math-font-style="normal"] {
  font-style: normal;
}


/* change of size induced by changing the scriptlevel */

[-moz-math-font-size="+1"] {
  font-size: 71%;
}
[-moz-math-font-size="+2"] {
  font-size: 50%;
}
[-moz-math-font-size="+3"] {
  font-size: 36%;
}
[-moz-math-font-size="+4"] {
  font-size: 25%;
}
[-moz-math-font-size="+5"] {
  font-size: 18%;
}
[-moz-math-font-size="scriptminsize"] {
  font-size: 8pt;
}
[-moz-math-font-size="-1"] {
  font-size: 141%;
}
[-moz-math-font-size="-2"] {
  font-size: 200%;
}
[-moz-math-font-size="-3"] {
  font-size: 283%;
}
[-moz-math-font-size="-4"] {
  font-size: 400%;
}
[-moz-math-font-size="-5"] {
  font-size: 566%;
}


/* style used for stretchy symbols */

:-moz-math-font-style-stretchy {
  font-style: normal;
  font-family: CMSY10, CMEX10, Math4, MT Extra, Symbol /* ,Math1, Math3, Math4, Math5 */ , serif;
/*  background-color: #3C6; */
}

:-moz-math-font-style-anonymous {
}





/**************************************************************************/
/* ALL THESE ARE USED FOR DEMO AND DEBUGGING PURPOSES ONLY                */
/* They may go away at any time                                           */
/**************************************************************************/


[background="yellow"] {
   background-color: yellow;
}

/*
maction:hover  { 
  outline: thick solid black;
  border: 1px dotted black;
}
*/

maction {
  background-color: yellow;
/*  border: 1px solid black; */
}

maction[actiontype="restyle#background"] {
  background-color: #3C6;
  border: 1px dotted red;
}

maction[actiontype="restyle#zoom"] {
  font-size: 40pt;
}

/*
mmultiscripts {
   background-color: yellow;
}
*/

/*
mtext {
   color: purple;
   border: 1px solid purple;
}
*/

/*
mstyle {
   background-color: yellow;
   border: 1px solid black;
}
*/

ms {
   color: blue;
/*
   background-color: yellow;
   border: 1px solid black;
*/
}

/*
mpadded {
  background-color: yellow;
  border: 1px solid black;
}
*/

/*
mspace {
}
*/

/*
msqrt, mroot {
  border: 1px dotted red;
  background-color: green;
}
*/

/*
mrow {
  border: 1px solid black;
  font-style: italic;
}
*/

/*
mphantom {
}
*/

/*
mfrac {
  background-color: blue;
  font-size: smaller;
  border: 1px dotted black;
}
*/

/*
msub, msup {
  background-color: yellow;
  border: 1px dotted black;
  font-size: small;
}
*/

/*
mclip {
  color: red;
  font-style: normal;
  border: 1px dashed green;
  background-color: yellow;
}
*/

/*
mn {
  border: 1px solid black;
}
*/

mi {
  color: red; 
/*  font-style: normal; */
/*  border: 1px dashed green; */
/*  background-color: yellow; */
}

/*
mo {
  font-family: CMEX10, Math1, Math3, Math4;
  font-style: normal;
  border: 1px solid black;
  background-color: lightyellow;
}
*/

/*
munder, mover, munderover {
  background-color: yellow;
  border: 1px solid black;
}
*/
